==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkIdList.java <==
// java wrapper for vtkIdList object
//

package vtk;
import vtk.*;

public class vtkIdList extends vtkObject
{

  private native void Initialize_0();
  public void Initialize()
    { Initialize_0(); }

  private native int Allocate_1(int id0,int id1);
  public int Allocate(int id0,int id1)
    { return Allocate_1(id0,id1); }

  private native String GetClassName_2();
  public String GetClassName()
    { return GetClassName_2(); }

  private native int IsA_3(String id0);
  public int IsA(String id0)
    { return IsA_3(id0); }

  private native int GetNumberOfIds_4();
  public int GetNumberOfIds()
    { return GetNumberOfIds_4(); }

  private native int GetId_5(int id0);
  public int GetId(int id0)
    { return GetId_5(id0); }

  private native void SetNumberOfIds_6(int id0);
  public void SetNumberOfIds(int id0)
    { SetNumberOfIds_6(id0); }

  private native void SetId_7(int id0,int id1);
  public void SetId(int id0,int id1)
    { SetId_7(id0,id1); }

  private native void InsertId_8(int id0,int id1);
  public void InsertId(int id0,int id1)
    { InsertId_8(id0,id1); }

  private native int InsertNextId_9(int id0);
  public int InsertNextId(int id0)
    { return InsertNextId_9(id0); }

  private native int InsertUniqueId_10(int id0);
  public int InsertUniqueId(int id0)
    { return InsertUniqueId_10(id0); }

  private native void Reset_11();
  public void Reset()
    { Reset_11(); }

  private native void Squeeze_12();
  public void Squeeze()
    { Squeeze_12(); }

  private native void DeepCopy_13(vtkIdList id0);
  public void DeepCopy(vtkIdList id0)
    { DeepCopy_13(id0); }

  private native void DeleteId_14(int id0);
  public void DeleteId(int id0)
    { DeleteId_14(id0); }

  private native int IsId_15(int id0);
  public int IsId(int id0)
    { return IsId_15(id0); }

  private native void IntersectWith_16(vtkIdList id0);
  public void IntersectWith(vtkIdList id0)
    { IntersectWith_16(id0); }

  public vtkIdList() { super(); }

  public vtkIdList(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-3-armv6h.pkg.tar.xz: vtk/vtkIdList.java <==
// java wrapper for vtkIdList object
//

package vtk;
import vtk.*;

public class vtkIdList extends vtkObject
{

  private native void Initialize_0();
  public void Initialize()
    { Initialize_0(); }

  private native int Allocate_1(int id0,int id1);
  public int Allocate(int id0,int id1)
    { return Allocate_1(id0,id1); }

  private native int IsTypeOf_2(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_2(id0); }

  private native int IsA_3(String id0);
  public int IsA(String id0)
    { return IsA_3(id0); }

  private native int GetNumberOfIds_4();
  public int GetNumberOfIds()
    { return GetNumberOfIds_4(); }

  private native int GetId_5(int id0);
  public int GetId(int id0)
    { return GetId_5(id0); }

  private native void SetNumberOfIds_6(int id0);
  public void SetNumberOfIds(int id0)
    { SetNumberOfIds_6(id0); }

  private native void SetId_7(int id0,int id1);
  public void SetId(int id0,int id1)
    { SetId_7(id0,id1); }

  private native void InsertId_8(int id0,int id1);
  public void InsertId(int id0,int id1)
    { InsertId_8(id0,id1); }

  private native int InsertNextId_9(int id0);
  public int InsertNextId(int id0)
    { return InsertNextId_9(id0); }

  private native int InsertUniqueId_10(int id0);
  public int InsertUniqueId(int id0)
    { return InsertUniqueId_10(id0); }

  private native void Reset_11();
  public void Reset()
    { Reset_11(); }

  private native void Squeeze_12();
  public void Squeeze()
    { Squeeze_12(); }

  private native void DeepCopy_13(vtkIdList id0);
  public void DeepCopy(vtkIdList id0)
    { DeepCopy_13(id0); }

  private native void DeleteId_14(int id0);
  public void DeleteId(int id0)
    { DeleteId_14(id0); }

  private native int IsId_15(int id0);
  public int IsId(int id0)
    { return IsId_15(id0); }

  private native void IntersectWith_16(vtkIdList id0);
  public void IntersectWith(vtkIdList id0)
    { IntersectWith_16(id0); }

  public vtkIdList() { super(); }

  public vtkIdList(long id) { super(id); }
  public native long   VTKInit();

}
